@@ -45,62 +45,120 @@
 _Atomic(bool) g_invoked_by_znc_jump_net = false;
 
 static stringarray_t znc_commands = {
-	"Version",
-	"ListMods",
-	"ListAvailMods",
-	"ListNicks",
-	"ListServers",
+	"AddMOTD",
 	"AddNetwork",
-	"DelNetwork",
-	"ListNetworks",
-	"MoveNetwork",
-	"JumpNetwork",
+	"AddPort",
 	"AddServer",
-	"DelServer",
 	"AddTrustedServerFingerprint",
-	"DelTrustedServerFingerprint",
-	"ListTrustedServerFingerprints",
-	"EnableChan",
-	"DisableChan",
 	"Attach",
-	"Detach",
-	"Topics",
-	"PlayBuffer",
-	"ClearBuffer",
+	"Broadcast",
 	"ClearAllBuffers",
 	"ClearAllChannelBuffers",
 	"ClearAllQueryBuffers",
-	"SetBuffer",
-	"SetBindHost",
-	"SetUserBindHost",
 	"ClearBindHost",
-	"ClearUserBindHost",
-	"ShowBindHost",
-	"Jump",
-	"Disconnect",
-	"Connect",
-	"Uptime",
-	"LoadMod",
-	"UnloadMod",
-	"ReloadMod",
-	"UpdateMod",
-	"ShowMOTD",
-	"SetMOTD",
-	"AddMOTD",
+	"ClearBuffer",
 	"ClearMOTD",
-	"ListPorts",
-	"AddPort",
+	"ClearUserBindHost",
+	"Connect",
+	"DelNetwork",
 	"DelPort",
-	"Rehash",
-	"SaveConfig",
-	"ListUsers",
+	"DelServer",
+	"DelTrustedServerFingerprint",
+	"Detach",
+	"DisableChan",
+	"Disconnect",
+	"EnableChan",
+	"Jump",
+	"JumpNetwork",
 	"ListAllUserNetworks",
+	"ListAvailMods",
 	"ListChans",
 	"ListClients",
-	"Traffic",
-	"Broadcast",
-	"Shutdown",
+	"ListMods",
+	"ListNetworks",
+	"ListNicks",
+	"ListPorts",
+	"ListServers",
+	"ListTrustedServerFingerprints",
+	"ListUsers",
+	"LoadMod",
+	"MoveNetwork",
+	"PlayBuffer",
+	"Rehash",
+	"ReloadMod",
 	"Restart",
+	"SaveConfig",
+	"SetBindHost",
+	"SetBuffer",
+	"SetMOTD",
+	"SetUserBindHost",
+	"ShowBindHost",
+	"ShowMOTD",
+	"Shutdown",
+	"Topics",
+	"Traffic",
+	"UnloadMod",
+	"UpdateMod",
+	"Uptime",
+	"Version",
+
+	// In lowercase as well...
+	"addmotd",
+	"addnetwork",
+	"addport",
+	"addserver",
+	"addtrustedserverfingerprint",
+	"attach",
+	"broadcast",
+	"clearallbuffers",
+	"clearallchannelbuffers",
+	"clearallquerybuffers",
+	"clearbindhost",
+	"clearbuffer",
+	"clearmotd",
+	"clearuserbindhost",
+	"connect",
+	"delnetwork",
+	"delport",
+	"delserver",
+	"deltrustedserverfingerprint",
+	"detach",
+	"disablechan",
+	"disconnect",
+	"enablechan",
+	"jump",
+	"jumpnetwork",
+	"listallusernetworks",
+	"listavailmods",
+	"listchans",
+	"listclients",
+	"listmods",
+	"listnetworks",
+	"listnicks",
+	"listports",
+	"listservers",
+	"listtrustedserverfingerprints",
+	"listusers",
+	"loadmod",
+	"movenetwork",
+	"playbuffer",
+	"rehash",
+	"reloadmod",
+	"restart",
+	"saveconfig",
+	"setbindhost",
+	"setbuffer",
+	"setmotd",
+	"setuserbindhost",
+	"showbindhost",
+	"showmotd",
+	"shutdown",
+	"topics",
+	"traffic",
+	"unloadmod",
+	"updatemod",
+	"uptime",
+	"version",
 };
 
 static void
