@@ -1,5 +1,5 @@
 /* User configuration
-   Copyright (C) 2012-2024 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2025 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -32,6 +32,9 @@
 #if UNIX
 #include <sys/mman.h>
 #endif
+#if __OpenBSD__
+#include <sys/param.h>
+#endif
 
 #include "config.h"
 #include "errHand.h"
@@ -84,12 +87,21 @@ static struct tagConfDefValues {
 	{ "username",                  TYPE_STRING,  2, "" },
 	{ "real_name",                 TYPE_STRING,  2, "" },
 
+	{ "ctcp_reply",                TYPE_BOOLEAN, 2, "yes" },
+	{ "ctcp_userinfo",             TYPE_STRING,  2, "No info set" },
+
 	{ "dcc",                       TYPE_BOOLEAN, 3, "yes" },
 	{ "dcc_cipher_suite",          TYPE_STRING,  1, "compat" },
 	{ "dcc_own_ip",                TYPE_STRING,  2, "" },
 	{ "dcc_port",                  TYPE_INTEGER, 2, "8080" },
 	{ "dcc_upload_dir",            TYPE_STRING,  2, "" },
 
+	{ "ftp_host",                  TYPE_STRING,  2, "" },
+	{ "ftp_port",                  TYPE_INTEGER, 2, "21" },
+	{ "ftp_user",                  TYPE_STRING,  2, "anonymous" },
+	{ "ftp_pass",                  TYPE_STRING,  2, "anonymous" },
+	{ "ftp_upload_dir",            TYPE_STRING,  2, "" },
+
 	{ "identd",                    TYPE_BOOLEAN, 3, "no" },
 	{ "identd_fakenames",          TYPE_BOOLEAN, 1, "no" },
 	{ "identd_port",               TYPE_INTEGER, 2, "113" },
@@ -139,7 +151,6 @@ static struct tagConfDefValues {
 	{ "cmd_hist_size",             TYPE_INTEGER, 3, "50" },
 	{ "cmd_type_prot",             TYPE_BOOLEAN, 3, "yes" },
 	{ "connection_timeout",        TYPE_INTEGER, 2, "45" },
-	{ "ctcp_reply",                TYPE_BOOLEAN, 3, "yes" },
 	{ "hostname_checking",         TYPE_BOOLEAN, 2, "yes" },
 	{ "iconv_conversion",          TYPE_BOOLEAN, 2, "yes" },
 	{ "joins_parts_quits",         TYPE_BOOLEAN, 2, "no" },
@@ -199,7 +210,8 @@ get_string(const char *name, const char *type)
 	(void) str.append(B1).append(type).append(B2);
 	(void) str.append(" ").append(Theme("notice_sep")).append(" ");
 
-	if (!strings_match(name, "sasl_password"))
+	if (!strings_match(name, "ftp_pass") &&
+	    !strings_match(name, "sasl_password"))
 		str.append(Config(name));
 	else
 		str.append(xstrnlen(Config(name), 80), '*');
@@ -299,11 +311,19 @@ output_values_for_all_settings(void)
 static void
 set_value_for_setting_ok_hook(const char *setting, const char *value)
 {
-	if (strings_match(setting, "mouse") ||
-	    strings_match(setting, "mouse_events"))
+	if (strings_match(setting, "dcc_upload_dir") ||
+	    strings_match(setting, "ftp_upload_dir")) {
+#if defined(OpenBSD) && OpenBSD >= 201811
+		printtext_print("warn", "OpenBSD uses unveil()  --  "
+		    "restart needed");
+#else
+		/* null */;
+#endif
+	} else if (strings_match(setting, "mouse") ||
+		   strings_match(setting, "mouse_events")) {
 		readline_mouse_init();
-	else if (strings_match(setting, "spell_lang") ||
-	    strings_match(setting, "spell_syswide")) {
+	} else if (strings_match(setting, "spell_lang") ||
+		   strings_match(setting, "spell_syswide")) {
 #ifdef HAVE_HUNSPELL
 		spell_deinit();
 		spell_init(true);
