@@ -42,6 +42,7 @@
 #include "../main.h"
 #include "../network.h"
 #include "../printtext.h"
+#include "../squeeze_text_deco.h"
 #include "../strHand.h"
 #include "../strdup_printf.h"
 #include "../terminal.h"
@@ -69,7 +70,7 @@
 /*
  * Notification message max length
  */
-static const size_t nmsg_maxlen = 150;
+static const size_t NMSG_MAXLEN = 150;
 
 static bool	shouldHighlightMessage_case1(CSTRING) NONNULL;
 static bool	shouldHighlightMessage_case2(CSTRING) NONNULL;
@@ -92,13 +93,14 @@ handle_special_msg(const struct special_msg_context *ctx)
 	PRINTTEXT_CONTEXT	ptext_ctx;
 	STRING			msg = sw_strdup(ctx->msg);
 
-	printtext_context_init(&ptext_ctx, NULL, TYPE_SPEC_NONE, true);
+	printtext_context_init(&ptext_ctx, nullptr, TYPE_SPEC_NONE, true);
 	squeeze(msg, "\x01");
 	msg = trim(msg);
 
 	if (strings_match_ignore_case(ctx->dest, g_my_nickname)) {
 		if (!strncmp(msg, "ACTION ", 7) &&
-		    (ptext_ctx.window = window_by_label(ctx->nick)) == NULL) {
+		    (ptext_ctx.window = window_by_label(ctx->nick)) ==
+		    nullptr) {
 			spawn_chat_window(ctx->nick,
 			    make_window_title(ctx->nick));
 		}
@@ -178,7 +180,7 @@ shouldHighlightMessage_case1(CSTRING msg)
 	if (!strncasecmp(msg, s1, strlen(s1)) ||
 	    !strncasecmp(msg, s2, strlen(s2)) ||
 	    !strncasecmp(msg, s3, strlen(s3)) ||
-	    strcasestr(msg, s4) != NULL ||
+	    strcasestr(msg, s4) != nullptr ||
 	    strings_match_ignore_case(msg, g_my_nickname))
 		result = true;
 	free(s1);
@@ -195,10 +197,10 @@ shouldHighlightMessage_case2(CSTRING msg)
 	char	*last = const_cast<char *>("");
 	char	*nickname_aliases = sw_strdup(Config("nickname_aliases"));
 
-	for (char *cp = &nickname_aliases[0];; cp = NULL) {
+	for (char *cp = &nickname_aliases[0];; cp = nullptr) {
 		CSTRING token;
 
-		if ((token = strtok_r(cp, " ", &last)) == NULL) {
+		if ((token = strtok_r(cp, " ", &last)) == nullptr) {
 			result = false;
 			break;
 		} else if (!is_valid_nickname(token)) {
@@ -268,7 +270,7 @@ handle_msgs_from_my_server(PPRINTTEXT_CONTEXT ctx, CSTRING dest,
 {
 	if (g_my_nickname && strings_match_ignore_case(dest, g_my_nickname))
 		ctx->window = g_active_window;
-	else if ((ctx->window = window_by_label(dest)) == NULL)
+	else if ((ctx->window = window_by_label(dest)) == nullptr)
 		ctx->window = g_active_window;
 	printtext(ctx, "%s!%s%s %s", COLOR3, g_server_hostname, TXT_NORMAL,
 	    msg);
@@ -281,54 +283,110 @@ handle_znc_msgs(PPRINTTEXT_CONTEXT ctx, CSTRING notice, CSTRING msg)
 	printtext(ctx, "%s %s", notice, msg);
 }
 
+/*
+ * Notify private message
+ */
+static void
+notify_pm(CSTRING p_nick, CSTRING p_msg)
+{
+	if (config_bool("notifications", true)) {
+#if defined(WIN32) && defined(TOAST_NOTIFICATIONS)
+		wchar_t *wNick = get_converted_wcs(p_nick);
+		wchar_t *wMsg = get_converted_wcs(p_msg);
+
+		Toasts::SendBasicToast(get_message(L"[PM]", L" <", wNick, L"> ",
+		    wMsg));
+		delete[] wNick;
+		delete[] wMsg;
+#elif defined(UNIX) && USE_LIBNOTIFY
+		STRING			 body;
+		NotifyNotification	*notification;
+
+		body = strdup_printf("[PM] &lt;%s&gt; %s", p_nick, p_msg);
+		notification = notify_notification_new(SUMMARY_TEXT, body,
+		    SWIRC_ICON_PATH);
+		notify_notification_show(notification, nullptr);
+		free(body);
+		g_object_unref(G_OBJECT(notification));
+#else
+		UNUSED_PARAM(p_nick);
+		UNUSED_PARAM(p_msg);
+		debug("%s called", __func__);
+#endif
+	}
+}
+
 static void
 handle_private_msgs(PPRINTTEXT_CONTEXT ctx, CSTRING nick, CSTRING msg)
 {
 	STRING msg_copy;
 
-	if ((ctx->window = window_by_label(nick)) == NULL)
+	if ((ctx->window = window_by_label(nick)) == nullptr)
 		throw std::runtime_error("window lookup error");
 
 	printtext(ctx, "%s%s%s%c%s %s", NICK_S1, COLOR2, nick, NORMAL, NICK_S2,
 	    msg);
-	msg_copy = sw_strdup(msg);
-	if (strlen(msg_copy) > nmsg_maxlen)
-		msg_copy[nmsg_maxlen] = '\0';
-
-#if defined(WIN32) && defined(TOAST_NOTIFICATIONS)
-	wchar_t *wNick = get_converted_wcs(nick);
-	wchar_t *wMsg = get_converted_wcs(msg_copy);
-
-	Toasts::SendBasicToast(get_message(L"[PM]", L" <", wNick, L"> ", wMsg));
-
-	delete[] wNick;
-	delete[] wMsg;
-#elif defined(UNIX) && USE_LIBNOTIFY
-	STRING body = strdup_printf("[PM] &lt;%s&gt; %s", nick, msg_copy);
-	NotifyNotification *notification = notify_notification_new(SUMMARY_TEXT,
-	    body, SWIRC_ICON_PATH);
-
-	notify_notification_show(notification, NULL);
-
-	free(body);
-	g_object_unref(G_OBJECT(notification));
-#endif
-
-	free(msg_copy);
 	if (ctx->window != g_active_window)
 		broadcast_window_activity(ctx->window);
+	if (!config_bool("notifications", true))
+		return;
+
+	msg_copy = sw_strdup(msg);
+
+	if (strlen(msg_copy) > NMSG_MAXLEN)
+		msg_copy[NMSG_MAXLEN] = '\0';
+	if (strpbrk(msg_copy, g_textdeco_chars) != nullptr)
+		(void)squeeze_text_deco(msg_copy);
+	notify_pm(nick, msg_copy);
+	free(msg_copy);
+}
+
+/*
+ * Notify channel message
+ */
+static void
+notify_cm(CSTRING p_nick, CSTRING p_dest, CSTRING p_msg)
+{
+	if (config_bool("notifications", true)) {
+#if defined(WIN32) && defined(TOAST_NOTIFICATIONS)
+		wchar_t *wNick = get_converted_wcs(p_nick);
+		wchar_t *wDest = get_converted_wcs(p_dest);
+		wchar_t *wMsg = get_converted_wcs(p_msg);
+
+		Toasts::SendBasicToast(get_message(wNick, L" @ ", wDest, L": ",
+		    wMsg));
+		delete[] wNick;
+		delete[] wDest;
+		delete[] wMsg;
+#elif defined(UNIX) && USE_LIBNOTIFY
+		STRING			 body;
+		NotifyNotification	*notification;
+
+		body = strdup_printf("%s @ %s: %s", p_nick, p_dest, p_msg);
+		notification = notify_notification_new(SUMMARY_TEXT, body,
+		    SWIRC_ICON_PATH);
+		notify_notification_show(notification, nullptr);
+		free(body);
+		g_object_unref(G_OBJECT(notification));
+#else
+		UNUSED_PARAM(p_nick);
+		UNUSED_PARAM(p_dest);
+		UNUSED_PARAM(p_msg);
+		debug("%s called", __func__);
+#endif
+	}
 }
 
 static void
 handle_chan_msgs(PPRINTTEXT_CONTEXT ctx, CSTRING nick, CSTRING dest,
     CSTRING msg)
 {
-	PNAMES	n = NULL;
+	PNAMES	n = nullptr;
 	char	c = '!';
 
-	if ((ctx->window = window_by_label(dest)) == NULL) {
+	if ((ctx->window = window_by_label(dest)) == nullptr) {
 		throw std::runtime_error("bogus window label");
-	} else if ((n = event_names_htbl_lookup(nick, dest)) != NULL) {
+	} else if ((n = event_names_htbl_lookup(nick, dest)) != nullptr) {
 		if (n->is_owner)
 			c = '~';
 		else if (n->is_superop)
@@ -350,38 +408,18 @@ handle_chan_msgs(PPRINTTEXT_CONTEXT ctx, CSTRING nick, CSTRING dest,
 		printtext(ctx, "%s%c%s%s%c%s %s",
 		    NICK_S1, c, COLOR4, nick, NORMAL, NICK_S2,
 		    msg);
-		msg_copy = sw_strdup(msg);
-		if (strlen(msg_copy) > nmsg_maxlen)
-			msg_copy[nmsg_maxlen] = '\0';
-
 		if (ctx->window != g_active_window)
 			broadcast_window_activity(ctx->window);
+		if (!config_bool("notifications", true))
+			return;
 
-#if defined(WIN32) && defined(TOAST_NOTIFICATIONS)
-		wchar_t *wNick = get_converted_wcs(nick);
-		wchar_t *wDest = get_converted_wcs(dest);
-		wchar_t *wMsg = get_converted_wcs(msg_copy);
+		msg_copy = sw_strdup(msg);
 
-		if (config_bool("notifications", true)) {
-			Toasts::SendBasicToast(get_message(wNick, L" @ ", wDest,
-			    L": ", wMsg));
-		}
-
-		delete[] wNick;
-		delete[] wDest;
-		delete[] wMsg;
-#elif defined(UNIX) && USE_LIBNOTIFY
-		STRING body = strdup_printf("%s @ %s: %s", nick, dest,
-		    msg_copy);
-		NotifyNotification *notification = notify_notification_new
-		    (SUMMARY_TEXT, body, SWIRC_ICON_PATH);
-
-		if (config_bool("notifications", true))
-			notify_notification_show(notification, NULL);
-
-		free(body);
-		g_object_unref(G_OBJECT(notification));
-#endif
+		if (strlen(msg_copy) > NMSG_MAXLEN)
+			msg_copy[NMSG_MAXLEN] = '\0';
+		if (strpbrk(msg_copy, g_textdeco_chars) != nullptr)
+			(void)squeeze_text_deco(msg_copy);
+		notify_cm(nick, dest, msg_copy);
 		free(msg_copy);
 	} else {
 		/*
@@ -406,13 +444,13 @@ event_privmsg(struct irc_message_compo *compo)
 	PRINTTEXT_CONTEXT	ctx;
 
 	try {
-		char *dest, *msg;
-		char *nick, *user, *host;
-		char *prefix;
-		char *state1 = const_cast<char *>("");
-		char *state2 = const_cast<char *>("");
+		CSTRING	dest, msg;
+		CSTRING	nick, user, host;
+		STRING	prefix;
+		STRING	state[2];
 
-		printtext_context_init(&ctx, NULL, TYPE_SPEC_NONE, true);
+		printtext_context_init(&ctx, nullptr, TYPE_SPEC_NONE, true);
+		state[0] = state[1] = const_cast<STRING>("");
 
 		if (has_server_time(compo)) {
 			set_timestamp(ctx.server_time,
@@ -420,16 +458,17 @@ event_privmsg(struct irc_message_compo *compo)
 			ctx.has_server_time = true;
 		}
 
-		if ((prefix = compo->prefix) == NULL)
+		if ((prefix = compo->prefix) == nullptr)
 			throw std::runtime_error("no prefix");
 		else if (*prefix == ':')
 			prefix++;
 
 		if (strFeed(compo->params, 1) != 1)
 			throw std::runtime_error("strFeed");
-		if ((dest = strtok_r(compo->params, "\n", &state2)) == NULL)
+		if ((dest = strtok_r(compo->params, "\n", &state[1])) ==
+		    nullptr)
 			throw std::runtime_error("no destination");
-		else if ((msg = strtok_r(NULL, "\n", &state2)) == NULL)
+		else if ((msg = strtok_r(nullptr, "\n", &state[1])) == nullptr)
 			throw std::runtime_error("no message");
 		else if (*msg == ':')
 			msg++;
@@ -440,12 +479,12 @@ event_privmsg(struct irc_message_compo *compo)
 			return;
 		}
 
-		if ((nick = strtok_r(prefix, "!@", &state1)) == NULL)
+		if ((nick = strtok_r(prefix, "!@", &state[0])) == nullptr)
 			throw std::runtime_error("no nickname");
-		if ((user = strtok_r(NULL, "!@", &state1)) == NULL)
-			user = const_cast<char *>("<no user>");
-		if ((host = strtok_r(NULL, "!@", &state1)) == NULL)
-			host = const_cast<char *>("<no host>");
+		if ((user = strtok_r(nullptr, "!@", &state[0])) == nullptr)
+			user = "<no user>";
+		if ((host = strtok_r(nullptr, "!@", &state[0])) == nullptr)
+			host = "<no host>";
 		if (is_in_ignore_list(nick, user, host))
 			return;
 
@@ -459,13 +498,13 @@ event_privmsg(struct irc_message_compo *compo)
 
 		if (strings_match_ignore_case(dest, g_my_nickname)) {
 			if (*nick == '*' && !g_icb_mode) {
-				char *notice;
+				STRING notice;
 
 				notice = get_notice(nick + 1, "znc", "znc.in");
 				handle_znc_msgs(&ctx, notice, msg);
 				free(notice);
 			} else {
-				if (window_by_label(nick) == NULL &&
+				if (window_by_label(nick) == nullptr &&
 				    spawn_chat_window(nick,
 				    make_window_title(nick)) != 0) {
 					throw std::runtime_error("cannot spawn "
@@ -478,7 +517,7 @@ event_privmsg(struct irc_message_compo *compo)
 			 * Dest is an IRC channel
 			 */
 
-			if (window_by_label(dest) == NULL &&
+			if (window_by_label(dest) == nullptr &&
 			    spawn_chat_window(dest, "No title.") != 0)
 				throw std::runtime_error("spawn_chat_window");
 			handle_chan_msgs(&ctx, nick, dest, msg);
