@@ -1,7 +1,7 @@
 #ifndef COMMAND_HELP_H
 #define COMMAND_HELP_H
 /* commandhelp.h
-   Copyright (C) 2018-2024 Markus Uhlin. All rights reserved.
+   Copyright (C) 2018-2025 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -114,6 +114,19 @@ static usage_t chanserv_usage = {
   "",
 };
 
+static usage_t ctcp_usage = {
+  N_("usage: /ctcp <query> <target>"),
+  "",
+  N_("Send a CTCP query to 'target', which is either a nickname or an IRC\n"
+     "channel."),
+  "",
+  N_("Query can be either:"),
+  "  - time",
+  "  - userinfo",
+  "  - version",
+  "",
+};
+
 static usage_t cap_usage = {
   N_("usage: /cap [ls | list]"),
   "",
@@ -186,10 +199,11 @@ static usage_t cycle_usage = {
 
 static usage_t dcc_usage = {
   N_("usage:"),
-  "    /dcc [clear|get|list|send] [args]",
+  "    /dcc [clear|get|list|ls|send] [args]",
   "    /dcc clear [get|send|completed|all]",
   "    /dcc get <nick> <file>",
   "    /dcc list [get|send|all]",
+  "    /dcc ls [up|down]",
   "    /dcc send <nick> <file>",
   "",
   N_("Get and send files. Swirc implements its own variant of DCC meaning\n"
@@ -264,6 +278,25 @@ static usage_t fetchdic_usage = {
   "",
 };
 
+static usage_t ftp_usage = {
+  N_("usage:"),
+  "    /ftp cd <path>",
+  "    /ftp del <path>",
+  "    /ftp exit",
+  "    /ftp get <file>",
+  "    /ftp login",
+  "    /ftp ls [dir|up|down]",
+  "    /ftp mkdir <path>",
+  "    /ftp pwd",
+  "    /ftp rmdir <path>",
+  "    /ftp send <file>",
+  "    /ftp system",
+  "",
+  N_("Retrieve and store files on a FTP server. (The communication is done\n"
+     "in clear text, i.e. unencrypted.)"),
+  "",
+};
+
 static usage_t gline_usage = {
   N_("usage: /gline <nick!user@host> [<duration> :<reason>]"),
   "",
