@@ -57,9 +57,11 @@
 #include "commands/cleartoasts.h"
 #include "commands/colormap.h"
 #include "commands/connect.h"
+#include "commands/ctcp.h"
 #include "commands/dcc.h"
 #include "commands/echo.h"
 #include "commands/fetchdic.h"
+#include "commands/ftp.h"
 #include "commands/ignore.h"
 #include "commands/info.h"
 #include "commands/invite.h"
@@ -114,6 +116,7 @@ static struct cmds_tag {
 	{ "colormap",    cmd_colormap,    false, colormap_usage,    ARRAY_SIZE(colormap_usage),    false },
 	{ "connect",     cmd_connect,     false, connect_usage,     ARRAY_SIZE(connect_usage),     false },
 	{ "cs",          cmd_chanserv,    true,  chanserv_usage,    ARRAY_SIZE(chanserv_usage),    true  },
+	{ "ctcp",        cmd_ctcp,        true,  ctcp_usage,        ARRAY_SIZE(ctcp_usage),        true  },
 	{ "cycle",       cmd_cycle,       true,  cycle_usage,       ARRAY_SIZE(cycle_usage),       true  },
 	{ "dcc",         cmd_dcc,         false, dcc_usage,         ARRAY_SIZE(dcc_usage),         true  },
 	{ "deop",        cmd_deop,        true,  deop_usage,        ARRAY_SIZE(deop_usage),        true  },
@@ -123,6 +126,7 @@ static struct cmds_tag {
 	{ "echo",        cmd_echo,        false, echo_usage,        ARRAY_SIZE(echo_usage),        false },
 	{ "exlist",      cmd_exlist,      true,  exlist_usage,      ARRAY_SIZE(exlist_usage),      true  },
 	{ "fetchdic",    cmd_fetchdic,    false, fetchdic_usage,    ARRAY_SIZE(fetchdic_usage),    false },
+	{ "ftp",         cmd_ftp,         false, ftp_usage,         ARRAY_SIZE(ftp_usage),         false },
 	{ "gline",       cmd_gline,       true,  gline_usage,       ARRAY_SIZE(gline_usage),       true  },
 	{ "group",       cmd_group,       true,  group_usage,       ARRAY_SIZE(group_usage),       false },
 	{ "help",        cmd_help,        false, help_usage,        ARRAY_SIZE(help_usage),        false },
@@ -750,8 +754,19 @@ enter_io_loop(void)
 				history_prev();
 
 			continue;
-		} else if (*line == cmd_char) {
+		} else if (*line == cmd_char && !sw_isdigit(line[1])) {
 			handle_cmds(&line[1]);
+		} else if (*line == cmd_char && sw_isdigit(line[1])) {
+			int refnum = 0;
+
+			if (sscanf(&line[1], "%d", &refnum) != 1) {
+				free_and_null(&line);
+				continue;
+			}
+
+			free_and_null(&line);
+			(void) change_window_by_refnum(refnum);
+			continue;
 		} else if (config_bool("cmd_type_prot", true) &&
 		    atomic_load_bool(&g_on_air) &&
 		    !strings_match(ACTWINLABEL, g_status_window_label) &&
