@@ -1,5 +1,5 @@
 /* libUtils.c  --  Library Utilities
-   Copyright (C) 2012-2024 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2025 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -29,6 +29,7 @@
 
 #include "common.h"
 
+#include <limits.h>
 #include <stdint.h>
 #include <string.h>
 #include <time.h>
@@ -40,6 +41,10 @@
 #include "libUtils.h"
 #include "strHand.h"
 
+#if defined(WIN32) && !defined(PATH_MAX)
+#define PATH_MAX 1024
+#endif
+
 #if defined(UNIX)
 #define PRINT_SIZE	"%zu"
 #elif defined(WIN32)
@@ -234,6 +239,25 @@ getuser(void)
 	return addrof(buf[0]);
 }
 
+int
+check_path(const char *p_base_dir, const char *p_full_path)
+{
+	char res[PATH_MAX] = { '\0' };
+
+	if (p_base_dir == NULL || p_full_path == NULL ||
+	    strings_match(p_base_dir, "") ||
+	    strings_match(p_full_path, ""))
+		return ERR;
+#if defined(UNIX)
+	if (realpath(p_full_path, res) == NULL)
+		return ERR;
+#elif defined(WIN32)
+	if (_fullpath(res, p_full_path, ARRAY_SIZE(res)) == NULL)
+		return ERR;
+#endif
+	return (strncmp(p_base_dir, res, strlen(p_base_dir)) == 0 ? OK : ERR);
+}
+
 /* Return the difference of 'a - b' */
 int
 int_diff(const int a, const int b)
