@@ -88,7 +88,7 @@
 /* Things with external linkage
    ============================ */
 
-chararray_t	g_swircVersion	= "v3.5.3";
+chararray_t	g_swircVersion	= "v3.5.4";
 chararray_t	g_swircYear	= "2012-2025";
 chararray_t	g_swircAuthor	= "Markus Uhlin";
 chararray_t	g_swircWebAddr	= "https://www.nifty-networks.net/swirc/";
@@ -165,6 +165,63 @@ static stringarray_t OptionDesc = {
   N_("    -x <config>          Config file\n"),
 };
 
+static void
+deal_with_setlocale()
+{
+#ifdef setlocale
+#undef setlocale
+#endif
+	xsetlocale = setlocale;
+
+	if (sw_strcpy(g_locale, xsetlocale(LC_ALL, ""), ARRAY_SIZE(g_locale)) ==
+	    0) {
+#ifdef HAVE_LIBINTL_SETLOCALE
+		xsetlocale = libintl_setlocale;
+
+		if (xsetlocale(LC_ALL, g_locale) == nullptr) {
+			err_quit("error setting character encoding '%s' for "
+			    "libintl", g_locale);
+		}
+#else
+		debug("set locale ok");
+#endif
+	}
+
+	xsetlocale = setlocale;
+}
+
+#if defined(HAVE_LIBINTL_H) && defined(WIN32)
+static void
+W32_have_libintl()
+{
+#define PEM_FILE "trusted_roots.pem"
+	char *cp, *pgm, *str;
+
+	cp = pgm = str = nullptr;
+
+	if (_get_pgmptr(&pgm) == 0 && pgm != nullptr &&
+	    !strings_match(pgm, "") &&
+	    !strings_match(&pgm[strspn(pgm, " \t")], "")) {
+		str = sw_strdup(pgm);
+		if ((cp = strcasestr(str, "\\swirc.exe")) == nullptr)
+			err_quit("renamed executable");
+		*cp = '\0';
+		g_progpath = sw_strdup(str);
+		while ((cp = strchr(str, SLASH_CHAR)) != nullptr)
+			*cp = '/';
+	}
+	if (bindtextdomain("swirc", (str ? str : "")) == nullptr)
+		err_sys("bindtextdomain");
+	if (str)
+		g_ca_file = strdup_printf("%s/%s", str, PEM_FILE);
+	else
+		g_ca_file = sw_strdup(PEM_FILE);
+	free(str);
+	if (pgm)
+		debug("_get_pgmptr: \"%s\"", pgm);
+}
+#endif
+
 static void
 swirc_terminate()
 {
@@ -509,6 +566,21 @@ get_seed()
 #endif
 }
 
+#if defined(UNIX) && defined(NDEBUG)
+static void
+forbid_core_dumps()
+{
+	struct rlimit rlim = { 0 };
+
+	if (getrlimit(RLIMIT_CORE, &rlim) == 0) {
+		rlim.rlim_cur = 0;
+		rlim.rlim_max = 0;
+		if (setrlimit(RLIMIT_CORE, &rlim) == 0)
+			debug("Core dumps are now forbidden");
+	}
+}
+#endif
+
 #if defined(WIN32) && defined(TOAST_NOTIFICATIONS)
 static void
 toast_notifications_init()
@@ -536,6 +608,47 @@ toast_notifications_init()
 }
 #endif
 
+#if defined(OpenBSD) && OpenBSD >= 201811
+static void
+unveil_doit()
+{
+	struct whitelist_tag {
+		const char	*path;
+		const char	*permissions;
+	} whitelist[] = {
+		{ "/etc/ssl/cert.pem", "r" },
+		{ LC_MSGS_DE, "r" },
+		{ LC_MSGS_FI, "r" },
+		{ LC_MSGS_FR, "r" },
+		{ LC_MSGS_SV, "r" },
+	};
+
+	if (unveil(g_home_dir, "rwc") == -1)
+		err_sys("unveil");
+
+	for (struct whitelist_tag *wl_p = addrof(whitelist[0]);
+	    wl_p < &whitelist[ARRAY_SIZE(whitelist)];
+	    wl_p++) {
+		errno = 0;
+
+		if (unveil(wl_p->path, wl_p->permissions) == -1 &&
+		    errno != ENOENT) {
+			err_sys("unveil(%s, %s)", wl_p->path,
+			    wl_p->permissions);
+		}
+	}
+
+	if (dcc::want_unveil_uploads()) {
+		if (unveil(dcc::get_upload_dir(), "r") == -1)
+			err_sys("unveil");
+	}
+	if (ftp::want_unveil_uploads()) {
+		if (unveil(ftp::get_upload_dir(), "r") == -1)
+			err_sys("unveil");
+	}
+}
+#endif
+
 /**
  * Starts execution
  */
@@ -564,24 +677,7 @@ main(int argc, char *argv[])
 	g_pid = _getpid();
 #endif
 
-#ifdef setlocale
-#undef setlocale
-#endif
-	xsetlocale = setlocale;
-	if (sw_strcpy(g_locale, xsetlocale(LC_ALL, ""), ARRAY_SIZE(g_locale)) ==
-	    0) {
-#ifdef HAVE_LIBINTL_SETLOCALE
-		xsetlocale = libintl_setlocale;
-		if (xsetlocale(LC_ALL, g_locale) == nullptr) {
-			err_msg("error setting character encoding '%s' for "
-			    "libintl", g_locale);
-			return EXIT_FAILURE;
-		}
-#else
-		debug("set locale ok");
-#endif
-	}
-	xsetlocale = setlocale;
+	deal_with_setlocale();
 
 #ifdef HAVE_LIBINTL_H
 #if defined(UNIX)
@@ -590,33 +686,9 @@ main(int argc, char *argv[])
 		return EXIT_FAILURE;
 	}
 #elif defined(WIN32)
-#define PEM_FILE "trusted_roots.pem"
-	char	*pgm = nullptr,
-		*str = nullptr;
-
-	if (_get_pgmptr(&pgm) == 0 && pgm != nullptr &&
-	    !strings_match(pgm, "") &&
-	    !strings_match(&pgm[strspn(pgm, " \t")], "")) {
-		str = sw_strdup(pgm);
-		if ((cp = strcasestr(str, "\\swirc.exe")) == nullptr) {
-			err_msg("renamed executable");
-			return EXIT_FAILURE;
-		}
-		*cp = '\0';
-		g_progpath = sw_strdup(str);
-		while ((cp = strchr(str, SLASH_CHAR)) != nullptr)
-			*cp = '/';
-	}
-	if (bindtextdomain("swirc", (str ? str : "")) == nullptr) {
-		err_ret("bindtextdomain");
-		return EXIT_FAILURE;
-	}
-	if (str)
-		g_ca_file = strdup_printf("%s/%s", str, PEM_FILE);
-	else
-		g_ca_file = sw_strdup(PEM_FILE);
-	free(str);
+	W32_have_libintl();
 #endif
+
 	(void) bind_textdomain_codeset("swirc", "UTF-8");
 
 	if (textdomain("swirc") == nullptr) {
@@ -668,10 +740,6 @@ main(int argc, char *argv[])
 
 	if ((g_dev_null = xfopen(DEV_NULL, "w")) == nullptr)
 		debug("dev null error");
-#if WIN32
-	if (pgm)
-		debug("_get_pgmptr: \"%s\"", pgm);
-#endif
 
 	if (curses_init() != OK) {
 		err_msg("%s", _("Initialization of the Curses library not "
@@ -687,14 +755,7 @@ main(int argc, char *argv[])
 	ftp_init();
 
 #if defined(UNIX) && defined(NDEBUG)
-	struct rlimit rlim = { 0 };
-
-	if (getrlimit(RLIMIT_CORE, &rlim) == 0) {
-		rlim.rlim_cur = 0;
-		rlim.rlim_max = 0;
-		if (setrlimit(RLIMIT_CORE, &rlim) == 0)
-			debug("Core dumps are now forbidden");
-	}
+	forbid_core_dumps();
 #else
 #pragma message("Omitted code to forbid core dumps")
 #endif
@@ -704,47 +765,7 @@ main(int argc, char *argv[])
 #endif
 
 #if defined(OpenBSD) && OpenBSD >= 201811
-	struct whitelist_tag {
-		const char	*path;
-		const char	*permissions;
-	} whitelist[] = {
-		{ "/etc/ssl/cert.pem", "r" },
-		{ LC_MSGS_DE, "r" },
-		{ LC_MSGS_FI, "r" },
-		{ LC_MSGS_FR, "r" },
-		{ LC_MSGS_SV, "r" },
-	};
-
-	if (unveil(g_home_dir, "rwc") == -1) {
-		err_ret("unveil");
-		return EXIT_FAILURE;
-	}
-
-	for (struct whitelist_tag *wl_p = addrof(whitelist[0]);
-	    wl_p < &whitelist[ARRAY_SIZE(whitelist)];
-	    wl_p++) {
-		errno = 0;
-
-		if (unveil(wl_p->path, wl_p->permissions) == -1 &&
-		    errno != ENOENT) {
-			err_ret("unveil(%s, %s)", wl_p->path,
-			    wl_p->permissions);
-			return EXIT_FAILURE;
-		}
-	}
-
-	if (dcc::want_unveil_uploads()) {
-		if (unveil(dcc::get_upload_dir(), "r") == -1) {
-			err_ret("unveil");
-			return EXIT_FAILURE;
-		}
-	}
-	if (ftp::want_unveil_uploads()) {
-		if (unveil(ftp::get_upload_dir(), "r") == -1) {
-			err_ret("unveil");
-			return EXIT_FAILURE;
-		}
-	}
+	unveil_doit();
 #endif
 
 #if defined(OpenBSD) && OpenBSD >= 201605
