@@ -12,6 +12,9 @@ extern char	*g_log_dir;
 extern char	*g_dcc_download_dir;
 extern char	*g_dcc_upload_dir;
 
+extern char	*g_ftp_download_dir;
+extern char	*g_ftp_upload_dir;
+
 extern const char	g_config_filesuffix[6];
 extern const char	g_theme_filesuffix[6];
 
