@@ -328,10 +328,6 @@ handle_conn_err(PPRINTTEXT_CONTEXT ptext_ctx, const char *what,
 		g_socket = INVALID_SOCKET;
 	}
 
-#ifdef WIN32
-	winsock_deinit();
-#endif
-
 	if (reconn_ctx.retry++ < reconn_ctx.retries) {
 		if (reconn_ctx.is_initial_attempt())
 			*sleep_time_seconds = reconn_ctx.delay;
@@ -432,12 +428,26 @@ send_reg_cmds(const struct network_connect_context *ctx)
 {
 	PRINTTEXT_CONTEXT ptext_ctx;
 
+	if (g_ircv3_extensions)
+		(void) net_send("CAP LS 302");
+
+	if (ctx->password)
+		(void) net_send("PASS %s", ctx->password);
+	(void) net_send("NICK %s", ctx->nickname);
+	(void) net_send("USER %s 8 * :%s", ctx->username, ctx->rl_name);
+
+	if (!g_ircv3_extensions)
+		return;
 	printtext_context_init(&ptext_ctx, g_status_window, TYPE_SPEC1_SUCCESS,
 	    true);
-	if (config_bool("account_notify", false)) {
+	if (config_bool("account_notify", true)) {
 		if (net_send("CAP REQ :account-notify") > 0)
 			printtext(&ptext_ctx, "Requesting account notify");
 	}
+	if (config_bool("account_tag", true)) {
+		if (net_send("CAP REQ :account-tag") > 0)
+			printtext(&ptext_ctx, "Requesting account tag");
+	}
 	if (config_bool("away_notify", false)) {
 		if (net_send("CAP REQ :away-notify") > 0)
 			printtext(&ptext_ctx, "Requesting away notify");
@@ -446,6 +456,14 @@ send_reg_cmds(const struct network_connect_context *ctx)
 		if (net_send("CAP REQ :batch") > 0)
 			printtext(&ptext_ctx, "Requesting batch");
 	}
+	if (config_bool("chghost", true)) {
+		if (net_send("CAP REQ :chghost") > 0)
+			printtext(&ptext_ctx, "Requesting change host");
+	}
+	if (config_bool("extended_join", true)) {
+		if (net_send("CAP REQ :extended-join") > 0)
+			printtext(&ptext_ctx, "Requesting extended join");
+	}
 	if (config_bool("invite_notify", false)) {
 		if (net_send("CAP REQ :invite-notify") > 0)
 			printtext(&ptext_ctx, "Requesting invite notify");
@@ -472,10 +490,6 @@ send_reg_cmds(const struct network_connect_context *ctx)
 			}
 		}
 	}
-	if (ctx->password)
-		(void) net_send("PASS %s", ctx->password);
-	(void) net_send("NICK %s", ctx->nickname);
-	(void) net_send("USER %s 8 * :%s", ctx->username, ctx->rl_name);
 }
 
 static bool
@@ -529,16 +543,6 @@ net_connect(const struct network_connect_context *ctx,
 	try {
 		ptext_ctx.spec_type = TYPE_SPEC1_SUCCESS;
 
-#ifdef WIN32
-		if (!winsock_init()) {
-			throw std::runtime_error(_("Cannot initiate use of the "
-			    "Winsock DLL"));
-		} else {
-			printtext(&ptext_ctx, "%s", _("Use of the Winsock DLL "
-			    "granted"));
-		}
-#endif
-
 		save_last_server(ctx->server, ctx->port, (ctx->password ?
 		    ctx->password : ""));
 		if (config_bool("identd", false))
@@ -747,7 +751,6 @@ net_irc_listen(bool *connection_lost)
 	recvbuf = static_cast<char *>(xmalloc(RECVBUF_SIZE + 1));
 	recvbuf[RECVBUF_SIZE] = '\0';
 	irc_init();
-	dcc::init();
 	netsplit_init();
 
 	do {
@@ -808,11 +811,7 @@ net_irc_listen(bool *connection_lost)
 		CLOSE_GLOBAL_SOCKET();
 		g_socket = INVALID_SOCKET;
 	}
-#ifdef WIN32
-	winsock_deinit();
-#endif
 	irc_deinit();
-	dcc::deinit();
 	netsplit_deinit();
 	free_and_null(&recvbuf);
 	free_and_null(&message_concat);
