@@ -1,5 +1,5 @@
 /* Read user input
-   Copyright (C) 2012-2024 Markus Uhlin. All rights reserved.
+   Copyright (C) 2012-2025 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -481,8 +481,10 @@ isInCirculationMode(const TAB_COMPLETION *tc)
 	    tc->isInCirculationModeFor.Cmds ||
 	    tc->isInCirculationModeFor.Connect ||
 	    tc->isInCirculationModeFor.Cs ||
+	    tc->isInCirculationModeFor.Dcc ||
 	    tc->isInCirculationModeFor.Deop ||
 	    tc->isInCirculationModeFor.Devoice ||
+	    tc->isInCirculationModeFor.Ftp ||
 	    tc->isInCirculationModeFor.Help ||
 	    tc->isInCirculationModeFor.Kick ||
 	    tc->isInCirculationModeFor.Kickban ||
