@@ -1,5 +1,5 @@
 /* spell.cpp
-   Copyright (C) 2023-2024 Markus Uhlin. All rights reserved.
+   Copyright (C) 2023-2025 Markus Uhlin. All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are met:
@@ -104,7 +104,7 @@ suggestion::get_word(void) const
 	return (this->word);
 }
 
-const wchar_t *
+CWSTRING
 suggestion::get_wide_word(void) const
 {
 	return (this->wide_word);
@@ -166,9 +166,7 @@ void
 spell_destroy_suggs(std::vector<sugg_ptr> *suggs)
 {
 	if (suggs) {
-		std::vector<sugg_ptr>::iterator it;
-
-		for (it = suggs->begin(); it != suggs->end(); ++it)
+		for (auto it = suggs->begin(); it != suggs->end(); ++it)
 			delete *it;
 
 		delete suggs;
@@ -177,7 +175,7 @@ spell_destroy_suggs(std::vector<sugg_ptr> *suggs)
 
 //lint -sem(get_mbs, r_null)
 static STRING
-get_mbs(const wchar_t *wcs)
+get_mbs(CWSTRING wcs)
 {
 	STRING	 out;
 	size_t	 bytes_convert, size;
@@ -196,7 +194,7 @@ get_mbs(const wchar_t *wcs)
 }
 
 std::vector<sugg_ptr> *
-spell_get_suggs(CSTRING mbs, const wchar_t *wcs)
+spell_get_suggs(CSTRING mbs, CWSTRING wcs)
 {
 	char**			 list;
 	int			 nsuggs;
@@ -250,30 +248,28 @@ spell_get_suggs(CSTRING mbs, const wchar_t *wcs)
 void
 spell_test1(CSTRING word)
 {
-	std::vector<sugg_ptr>			*suggs;
-	std::vector<sugg_ptr>::iterator		 it;
+	std::vector<sugg_ptr> *suggs;
 
 	printtext_print(nullptr, " -- %s is %s", word, (spell_word(word) ?
 	    "correct" : "incorrect"));
 
 	if ((suggs = spell_get_suggs(word, nullptr)) != nullptr) {
-		for (it = suggs->begin(); it != suggs->end(); ++it)
+		for (auto it = suggs->begin(); it != suggs->end(); ++it)
 			printtext_print(nullptr, "%s", (*it)->get_word());
 		spell_destroy_suggs(suggs);
 	}
 }
 
 void
-spell_test2(const wchar_t *word)
+spell_test2(CWSTRING word)
 {
-	std::vector<sugg_ptr>			*suggs;
-	std::vector<sugg_ptr>::iterator		 it;
+	std::vector<sugg_ptr> *suggs;
 
 	printtext_print(nullptr, " -- %ls is %s", word, (spell_wide_word(word) ?
 	    "correct" : "incorrect"));
 
 	if ((suggs = spell_get_suggs(nullptr, word)) != nullptr) {
-		for (it = suggs->begin(); it != suggs->end(); ++it)
+		for (auto it = suggs->begin(); it != suggs->end(); ++it)
 			printtext_print(nullptr, "%ls", (*it)->get_wide_word());
 		spell_destroy_suggs(suggs);
 	}
@@ -337,11 +333,9 @@ auto_complete_next_sugg(volatile struct readline_session_context *ctx)
 static void
 print_suggestions(std::vector<sugg_ptr> *suggs)
 {
-	std::vector<sugg_ptr>::iterator it;
-
 	printtext_print(nullptr, "%s", _("suggestions:"));
 
-	for (it = suggs->begin(); it != suggs->end(); ++it)
+	for (auto it = suggs->begin(); it != suggs->end(); ++it)
 		printtext_print(nullptr, "  %ls", (*it)->get_wide_word());
 }
 
@@ -392,7 +386,7 @@ spell_word_readline(volatile struct readline_session_context *ctx)
 }
 
 bool
-spell_wide_word(const wchar_t *word)
+spell_wide_word(CWSTRING word)
 {
 	STRING	mbs;
 	bool	ret;
